==> duiba-live-activity-center-api-0.0.3-sources.jar: cn/com/duiba/live/activity/center/api/remoteservice/red/RemoteLiveRedPacketReceiveService.java <==
package cn.com.duiba.live.activity.center.api.remoteservice.red;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.live.activity.center.api.dto.clue.LiveRedPacketReceiveDto;
import cn.com.duiba.live.activity.center.api.dto.clue.LiveRedPacketReceiveSumDto;
import cn.com.duiba.live.activity.center.api.param.red.LiveRedPacketReceiveSearchParam;
import cn.com.duiba.live.activity.center.api.param.red.LiveRedPacketDrawParam;

import java.util.List;
import java.util.Map;

/**
 * 领取记录
 * @author lizhi
 * @date 2020/6/19 1:59 PM
 */
@AdvancedFeignClient
public interface RemoteLiveRedPacketReceiveService {

    /**
     * 根据条件查询，分页
     * @param param 查询条件
     * @return 直播红包领取记录集合
     */
    List<LiveRedPacketReceiveDto> findPage(LiveRedPacketReceiveSearchParam param);

    /**
     * 根据领取记录ID，查询红包结果
     * @param id 领取记录ID
     * @return 领取结果
     */
    LiveRedPacketReceiveDto findById(Long id);

    /**
     * 根据主键批量查询
     * @param ids 主键集合
     * @return 领取记录集合
     */
    List<LiveRedPacketReceiveDto> findByIds(List<Long> ids);

    /**
     * 获取红包发放总金额
     * @param confRedPacketId 活动ID
     * @param receiveStatus 领取状态
     * @return
     */
    Long findTotalAmountByConfAndStatus(Long confRedPacketId, Integer receiveStatus);

    /**
     * 批量获取红包发放总金额
     * @param confRedPacketIds 活动IDs
     * @param receiveStatus 领取状态
     * @return
     */
    List<LiveRedPacketReceiveSumDto> findTotalAmountByConfIdsAndStatus(List<Long> confRedPacketIds, Integer receiveStatus);

    /**
     * 批量新增
     * @param dtoList 领取记录集合
     * @return key：直播用户ID，value：主键
     */
    Map<Long, Long> batchInsert(List<LiveRedPacketReceiveDto> dtoList);

    /**
     * 批量更新
     * @param dtoList 领取记录集合
     * @return 更新结果
     */
    int batchUpdate(List<LiveRedPacketReceiveDto> dtoList);

    /**
     * 领取红包
     * @param param 领红包参数
     * @return 领红包记录
     */
    LiveRedPacketReceiveDto drawRedPacket(LiveRedPacketDrawParam param);
}

==> duiba-live-activity-center-api-0.0.3-4-20210113.073531-1-sources.jar: cn/com/duiba/live/activity/center/api/remoteservice/red/RemoteLiveRedPacketReceiveService.java <==
package cn.com.duiba.live.activity.center.api.remoteservice.red;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.live.activity.center.api.dto.clue.LiveRedPacketReceiveDto;
import cn.com.duiba.live.activity.center.api.dto.clue.LiveRedPacketReceiveSumDto;
import cn.com.duiba.live.activity.center.api.param.red.LiveRedPacketReceiveSearchParam;
import cn.com.duiba.live.activity.center.api.param.red.LiveRedPacketDrawParam;

import java.util.List;
import java.util.Map;

/**
 * 领取记录
 * @author lizhi
 * @date 2020/6/19 1:59 PM
 */
@AdvancedFeignClient
public interface RemoteLiveRedPacketReceiveService {

    /**
     * 根据条件查询，分页
     * @param param 查询条件
     * @return 直播红包领取记录集合
     */
    List<LiveRedPacketReceiveDto> findPage(LiveRedPacketReceiveSearchParam param);

    /**
     * 根据领取记录ID，查询红包结果
     * @param id 领取记录ID
     * @return 领取结果
     */
    LiveRedPacketReceiveDto findById(Long id);

    /**
     * 根据主键批量查询
     * @param ids 主键集合
     * @return 领取记录集合
     */
    List<LiveRedPacketReceiveDto> findByIds(List<Long> ids);

    /**
     * 获取红包发放总金额
     * @param confRedPacketId 活动ID
     * @param receiveStatus 领取状态
     * @return
     */
    Long findTotalAmountByConfAndStatus(Long confRedPacketId, Integer receiveStatus);

    /**
     * 批量获取红包发放总金额
     * @param confRedPacketIds 活动IDs
     * @param receiveStatus 领取状态
     * @return
     */
    List<LiveRedPacketReceiveSumDto> findTotalAmountByConfIdsAndStatus(List<Long> confRedPacketIds, Integer receiveStatus);

    /**
     * 批量新增
     * @param dtoList 领取记录集合
     * @return key：直播用户ID，value：主键
     */
    Map<Long, Long> batchInsert(List<LiveRedPacketReceiveDto> dtoList);

    LiveRedPacketReceiveDto insert(LiveRedPacketReceiveDto dto);

    /**
     * 批量更新
     * @param dtoList 领取记录集合
     * @return 更新结果
     */
    Integer batchUpdate(List<LiveRedPacketReceiveDto> dtoList);

    /**
     * 领取红包
     * @param param 领红包参数
     * @return 领红包记录
     */
    LiveRedPacketReceiveDto drawRedPacket(LiveRedPacketDrawParam param);
}
